==> order-center-infrastructure-2.0.9-CLOUD-TEST-20220414.043105-84-sources.jar: com/tydic/dyc/oc/repository/po/UocCmpOrderItemPo.java <==
package com.tydic.dyc.oc.repository.po;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题:UocCmpOrderItemPo
 * 说明:比选明细表
 * 时间:2022-02-23 20:57
 * 作者:罗有
 **/
@Data
public class UocCmpOrderItemPo implements Serializable {
	private static final long serialVersionUID =  -2962530616411325212L;

	@DocField(value = "比选单明细id")
	private Long cmpOrderItemId;

	@DocField(value = "比选单id")
	private Long cmpOrderId;

	@DocField(value = "单品id	")
	private String skuId;

	@DocField(value = "商品id	")
	private String spuId;

	@DocField(value = "供应商id	")
	private String goodsSupplierId;

	@DocField(value = "所属供应商名称")
	private String goodsSupplierName;

	@DocField(value = "店铺id	")
	private String shopId;

	@DocField(value = "原商品购物车id(比选原商品必传)	")
	private String cartId;

	@DocField(value = "销售价")
	private String skuSalePrice;

	@DocField(value = "总价")
	private String totalSalePrice;

	@DocField(value = "销售单位")
	private String unitName;

	@DocField(value = "商品名称")
	private String skuName;

	@DocField(value = "数量")
	private String purchaseCount;

	@DocField(value = "规格")
	private String specification;

	@DocField(value = "图片地址	")
	private String imgUrl;

	@DocField(value = "是否暂无（是的传   暂无）	")
	private String nothing;

	@DocField(value = "排序（页面第几个）	")
	private Integer skuOrder;

	@DocField(value = "物料id")
	private String materialId;

	@DocField(value = "交货时间")
	private Date deliveryTime;

	@DocField(value = "品牌")
	private String brand;

	@DocField(value = "型号")
	private String model;

	@DocField(value = "销量")
	private BigDecimal saleCount;

	@DocField(value = "物料名称")
	private String materialName;

	@DocField(value = "上架时间")
	private Date shelvesTime;

	@DocField(value = "好评率")
	private BigDecimal positiveRate;

	@DocField(value = "售后服务政策")
	private String afsPolicy;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "排序")
	private String orderBy;

}

==> order-center-infrastructure-3.1.0-CLOUD-TEST-20230731.024100-76-sources.jar: com/tydic/dyc/oc/repository/po/UocCmpOrderItemPo.java <==
package com.tydic.dyc.oc.repository.po;


import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题:UocCmpOrderItemPo
 * 说明:比选明细表
 * 时间:2022-02-23 20:57
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocCmpOrderItemPo implements Serializable {
	private static final long serialVersionUID =  -2962530616411325212L;

	//比选单明细id")
	private Long cmpOrderItemId;

	//比选单id")
	private Long cmpOrderId;

	//单品id	")
	private String skuId;

	//商品id	")
	private String spuId;

	//供应商id	")
	private String goodsSupplierId;

	//所属供应商名称")
	private String goodsSupplierName;

	//店铺id	")
	private String shopId;

	//原商品购物车id(比选原商品必传)	")
	private String cartId;

	//销售价")
	private String skuSalePrice;

	//总价")
	private String totalSalePrice;

	//销售单位")
	private String unitName;

	//商品名称")
	private String skuName;

	//数量")
	private String purchaseCount;

	//规格")
	private String specification;

	//图片地址	")
	private String imgUrl;

	//是否暂无（是的传   暂无）	")
	private String nothing;

	//排序（页面第几个）	")
	private Integer skuOrder;

	//物料id")
	private String materialId;

	//交货时间")
	private Date deliveryTime;

	//交货时间字符串")
	//部分电商返回是字符串，用于向前兼容date类型，数据库增加一个String类型的字段
	private String deliveryTimeStr;

	//品牌")
	private String brand;

	//型号")
	private String model;

	//销量")
	private BigDecimal saleCount;

	//物料名称")
	private String materialName;

	//上架时间")
	private Date shelvesTime;

	//好评率")
	private BigDecimal positiveRate;

	//售后服务政策")
	private String afsPolicy;

	//创建时间")
	private Date createTime;

	//创建时间 开始")
	private Date createTimeStart;

	//创建时间 结束")
	private Date createTimeEnd;

	//创建工号")
	private String createOperId;

	//更新时间")
	private Date updateTime;

	//更新时间 开始")
	private Date updateTimeStart;

	//更新时间 结束")
	private Date updateTimeEnd;

	//更新工号")
	private String updateOperId;

	//备注")
	private String remark;

	//删除标志1已删除")
	private Integer delTag;

	//单品来源      1 自营单品   2 电商导入   3 协议生成")
	private Integer skuSource;

	//排序")
	private String orderBy;
    
    //供应商店铺id	")
    private String supplierShopId;
}
